# Penguin_analyst_boaz

This Project can Analyze your Penguins

```python
import penguin_analyst_boaz
df = penguin_analyst_boaz.get_penguins()
print(penguins_analyst_boaz.count_penguins() #344
print(penguins_analyst_boaz.islands())
```
